Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(312)

Unified Diff: pkg/analysis_server/lib/src/services/index/index.dart

Issue 1359113002: Use IndexContributor(s) in LocalIndex. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/index/index.dart
diff --git a/pkg/analysis_server/lib/src/services/index/index.dart b/pkg/analysis_server/lib/src/services/index/index.dart
index 41b5a0ab9310cea8edb968b1f06c50a6b3339cca..04e57ae9770700f8af6c80be04a41abb9a992302 100644
--- a/pkg/analysis_server/lib/src/services/index/index.dart
+++ b/pkg/analysis_server/lib/src/services/index/index.dart
@@ -6,12 +6,10 @@ library services.index;
import 'dart:async';
-import 'package:analysis_server/analysis/index/index_core.dart';
+import 'package:analysis_server/analysis/index_core.dart';
import 'package:analysis_server/src/services/index/indexable_element.dart';
-import 'package:analyzer/src/generated/ast.dart';
import 'package:analyzer/src/generated/element.dart';
import 'package:analyzer/src/generated/engine.dart';
-import 'package:analyzer/src/generated/html.dart';
import 'package:analyzer/src/generated/source.dart';
/**
@@ -45,20 +43,12 @@ abstract class Index implements IndexStore {
List<Element> getTopLevelDeclarations(ElementNameFilter nameFilter);
/**
* Processes the given [HtmlUnit] in order to record the relationships.
*
* [context] - the [AnalysisContext] in which [HtmlUnit] was resolved.
* [unit] - the [HtmlUnit] being indexed.
*/
- void indexHtmlUnit(AnalysisContext context, HtmlUnit unit);
-
- /**
- * Processes the given [CompilationUnit] in order to record the relationships.
- *
- * [context] - the [AnalysisContext] in which [CompilationUnit] was resolved.
- * [unit] - the [CompilationUnit] being indexed.
- */
- void indexUnit(AnalysisContext context, CompilationUnit unit);
+ void index(AnalysisContext context, Object object);
/**
* Starts the index.
@@ -45,20 +43,12 @@ abstract class Index implements IndexStore {
List<Element> getTopLevelDeclarations(ElementNameFilter nameFilter);
/**
- * Processes the given [HtmlUnit] in order to record the relationships.
+ * Processes the given [object] in order to record the relationships.
*
@@ -45,20 +43,12 @@ abstract class Index implements IndexStore {
*
- * [context] - the [AnalysisContext] in which [HtmlUnit] was resolved.
- * [unit] - the [HtmlUnit] being indexed.
+ * [context] - the [AnalysisContext] in which the [object] being indexed.
+ * [object] - the object being indexed.
*/

Powered by Google App Engine
This is Rietveld 408576698